# C++ Candid Library

The C++ Candid Library of [icpp](https://docs.icpp.world/)

## Status
The Candid Library is fully functional and it is embedded & tested in [icpp](https://docs.icpp.world/).

This GitHub repository is WIP, as we are still in the process of fully externalizing the Candid Library from the icpp cdk. We expect to complete it by July 19, but are already open sourcing it so you can check it out.


## Support
Interested to use our C++ Candid Library in your project?

We're excited to hear from you.

Join the [icpp users group at OpenChat](https://oc.app/group/tjvrf-oqaaa-aaaar-ahp6a-cai/?ref=6e3y2-4yaaa-aaaaf-araya-cai&code=9104f504fcd17b1f)

